==> ixnetwork_restpy-1.1.4.tar.gz: ixnetwork_restpy-1.1.4/ixnetwork_restpy/testplatform/sessions/ixnetwork/vport/protocols/queueproperty_a755ca2d7ba5959c2e5e1aa284875864.py <==
# MIT LICENSE
#
# Copyright 1997 - 2020 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE. 
import sys
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files
if sys.version_info >= (3, 5):
    from typing import List, Any, Union


class QueueProperty(Base):
    """An object that allows you to define the OpenFlow Queue property configurations.
    The QueueProperty class encapsulates a required queueProperty resource which will be retrieved from the server every time the property is accessed.
    """

    __slots__ = ()
    _SDM_NAME = 'queueProperty'
    _SDM_ATT_MAP = {
        'MaximumDataRate': 'maximumDataRate',
        'MinimumDataRateGuaranteed': 'minimumDataRateGuaranteed',
        'IsNone': 'none',
    }
    _SDM_ENUM_MAP = {
    }

    def __init__(self, parent, list_op=False):
        super(QueueProperty, self).__init__(parent, list_op)

    @property
    def MaximumDataRate(self):
        # type: () -> bool
        """
        Returns
        -------
        - bool: If true, indicates that a maximum data rate is guaranteed.
        """
        return self._get_attribute(self._SDM_ATT_MAP['MaximumDataRate'])
    @MaximumDataRate.setter
    def MaximumDataRate(self, value):
        # type: (bool) -> None
        self._set_attribute(self._SDM_ATT_MAP['MaximumDataRate'], value)

    @property
    def MinimumDataRateGuaranteed(self):
        # type: () -> bool
        """
        Returns
        -------
        - bool: If true, indicates that a minimum data rate is guaranteed.
        """
        return self._get_attribute(self._SDM_ATT_MAP['MinimumDataRateGuaranteed'])
    @MinimumDataRateGuaranteed.setter
    def MinimumDataRateGuaranteed(self, value):
        # type: (bool) -> None
        self._set_attribute(self._SDM_ATT_MAP['MinimumDataRateGuaranteed'], value)

    @property
    def IsNone(self):
        # type: () -> bool
        """
        Returns
        -------
        - bool: If true, indicates that no property is defined for the queue.
        """
        return self._get_attribute(self._SDM_ATT_MAP['IsNone'])
    @IsNone.setter
    def IsNone(self, value):
        # type: (bool) -> None
        self._set_attribute(self._SDM_ATT_MAP['IsNone'], value)

    def update(self, MaximumDataRate=None, MinimumDataRateGuaranteed=None):
        # type: (bool, bool) -> QueueProperty
        """Updates queueProperty resource on the server.

        Args
        ----
        - MaximumDataRate (bool): If true, indicates that a maximum data rate is guaranteed.
        - MinimumDataRateGuaranteed (bool): If true, indicates that a minimum data rate is guaranteed.

        Raises
        ------
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))

    def find(self, MaximumDataRate=None, MinimumDataRateGuaranteed=None, IsNone=None):
        # type: (bool, bool, bool) -> QueueProperty
        """Finds and retrieves queueProperty resources from the server.

        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve queueProperty resources from the server.
        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
        By default the find method takes no parameters and will retrieve all queueProperty resources from the server.

        Args
        ----
        - MaximumDataRate (bool): If true, indicates that a maximum data rate is guaranteed.
        - MinimumDataRateGuaranteed (bool): If true, indicates that a minimum data rate is guaranteed.
        - IsNone (bool): If true, indicates that no property is defined for the queue.

        Returns
        -------
        - self: This instance with matching queueProperty resources retrieved from the server available through an iterator or index

        Raises
        ------
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))

    def read(self, href):
        """Retrieves a single instance of queueProperty data from the server.

        Args
        ----
        - href (str): An href to the instance to be retrieved

        Returns
        -------
        - self: This instance with the queueProperty resources from the server available through an iterator or index

        Raises
        ------
        - NotFoundError: The requested resource does not exist on the server
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._read(href)

==> ixnetwork_restpy-1.1.11.tar.gz: ixnetwork_restpy-1.1.11/ixnetwork_restpy/testplatform/sessions/ixnetwork/vport/protocols/queueproperty_a755ca2d7ba5959c2e5e1aa284875864.py <==
# MIT LICENSE
#
# Copyright 1997 - 2020 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
import sys
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files

if sys.version_info >= (3, 5):
    from typing import List, Any, Union


class QueueProperty(Base):
    """An object that allows you to define the OpenFlow Queue property configurations.
    The QueueProperty class encapsulates a required queueProperty resource which will be retrieved from the server every time the property is accessed.
    """

    __slots__ = ()
    _SDM_NAME = "queueProperty"
    _SDM_ATT_MAP = {
        "MaximumDataRate": "maximumDataRate",
        "MinimumDataRateGuaranteed": "minimumDataRateGuaranteed",
        "IsNone": "none",
    }
    _SDM_ENUM_MAP = {}

    def __init__(self, parent, list_op=False):
        super(QueueProperty, self).__init__(parent, list_op)

    @property
    def MaximumDataRate(self):
        # type: () -> bool
        """
        Returns
        -------
        - bool: If true, indicates that a maximum data rate is guaranteed.
        """
        return self._get_attribute(self._SDM_ATT_MAP["MaximumDataRate"])

    @MaximumDataRate.setter
    def MaximumDataRate(self, value):
        # type: (bool) -> None
        self._set_attribute(self._SDM_ATT_MAP["MaximumDataRate"], value)

    @property
    def MinimumDataRateGuaranteed(self):
        # type: () -> bool
        """
        Returns
        -------
        - bool: If true, indicates that a minimum data rate is guaranteed.
        """
        return self._get_attribute(self._SDM_ATT_MAP["MinimumDataRateGuaranteed"])

    @MinimumDataRateGuaranteed.setter
    def MinimumDataRateGuaranteed(self, value):
        # type: (bool) -> None
        self._set_attribute(self._SDM_ATT_MAP["MinimumDataRateGuaranteed"], value)

    @property
    def IsNone(self):
        # type: () -> bool
        """
        Returns
        -------
        - bool: If true, indicates that no property is defined for the queue.
        """
        return self._get_attribute(self._SDM_ATT_MAP["IsNone"])

    @IsNone.setter
    def IsNone(self, value):
        # type: (bool) -> None
        self._set_attribute(self._SDM_ATT_MAP["IsNone"], value)

    def update(self, MaximumDataRate=None, MinimumDataRateGuaranteed=None):
        # type: (bool, bool) -> QueueProperty
        """Updates queueProperty resource on the server.

        Args
        ----
        - MaximumDataRate (bool): If true, indicates that a maximum data rate is guaranteed.
        - MinimumDataRateGuaranteed (bool): If true, indicates that a minimum data rate is guaranteed.

        Raises
        ------
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._update(self._map_locals(self._SDM_ATT_MAP, locals()))

    def find(self, MaximumDataRate=None, MinimumDataRateGuaranteed=None, IsNone=None):
        # type: (bool, bool, bool) -> QueueProperty
        """Finds and retrieves queueProperty resources from the server.

        All named parameters are evaluated on the server using regex. The named parameters can be used to selectively retrieve queueProperty resources from the server.
        To retrieve an exact match ensure the parameter value starts with ^ and ends with $
        By default the find method takes no parameters and will retrieve all queueProperty resources from the server.

        Args
        ----
        - MaximumDataRate (bool): If true, indicates that a maximum data rate is guaranteed.
        - MinimumDataRateGuaranteed (bool): If true, indicates that a minimum data rate is guaranteed.
        - IsNone (bool): If true, indicates that no property is defined for the queue.

        Returns
        -------
        - self: This instance with matching queueProperty resources retrieved from the server available through an iterator or index

        Raises
        ------
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._select(self._map_locals(self._SDM_ATT_MAP, locals()))

    def read(self, href):
        """Retrieves a single instance of queueProperty data from the server.

        Args
        ----
        - href (str): An href to the instance to be retrieved

        Returns
        -------
        - self: This instance with the queueProperty resources from the server available through an iterator or index

        Raises
        ------
        - NotFoundError: The requested resource does not exist on the server
        - ServerError: The server has encountered an uncategorized error condition
        """
        return self._read(href)
